import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/space_management_v2/main_module/shared/widgets/community_dialog.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/communities/presentation/bloc/communities_bloc.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/communities/presentation/communities_tree_selection_bloc/communities_tree_selection_bloc.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/create_community/data/services/remote_create_community_service.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/create_community/domain/param/create_community_param.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/create_community/presentation/bloc/create_community_bloc.dart';
import 'package:syncrow_web/services/api/http_service.dart';

class CreateCommunityDialog extends StatelessWidget {
  const CreateCommunityDialog({super.key});

  @override
  Widget build(BuildContext context) {
    return BlocProvider(
      create: (_) => CreateCommunityBloc(
        RemoteCreateCommunityService(HTTPService()),
      ),
      child: BlocConsumer<CreateCommunityBloc, CreateCommunityState>(
        listener: (context, state) {
          switch (state) {
            case CreateCommunityLoading():
              showDialog<void>(
                context: context,
                builder: (context) => const Center(
                  child: CircularProgressIndicator(),
                ),
              );
              break;
            case CreateCommunitySuccess(:final community):
              Navigator.of(context).pop();
              Navigator.of(context).pop();
              ScaffoldMessenger.of(context).showSnackBar(
                const SnackBar(content: Text('Community created successfully')),
              );
              context.read<CommunitiesBloc>().add(
                    InsertCommunity(community),
                  );
              context.read<CommunitiesTreeSelectionBloc>().add(
                    SelectCommunityEvent(community: community),
                  );
              break;
            case CreateCommunityFailure():
              Navigator.of(context).pop();
              break;
            default:
              break;
          }
        },
        builder: (BuildContext context, CreateCommunityState state) {
          return CommunityDialog(
            title: const Text('Create Community'),
            initialName: null,
            onSubmit: (name) => context.read<CreateCommunityBloc>().add(
                  CreateCommunity(CreateCommunityParam(name: name)),
                ),
            errorMessage: state is CreateCommunityFailure ? state.message : null,
          );
        },
      ),
    );
  }
}
