import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/space_management_v2/main_module/shared/widgets/community_dialog.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/communities/domain/models/community_model.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/update_community/data/services/remote_update_community_service.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/update_community/presentation/bloc/update_community_bloc.dart';
import 'package:syncrow_web/services/api/http_service.dart';

class EditCommunityDialog extends StatelessWidget {
  const EditCommunityDialog({required this.community, super.key});

  final CommunityModel community;

  @override
  Widget build(BuildContext context) {
    return BlocProvider(
      create: (_) =>
          UpdateCommunityBloc(RemoteUpdateCommunityService(HTTPService())),
      child: BlocConsumer<UpdateCommunityBloc, UpdateCommunityState>(
        listener: (context, state) {
          switch (state) {
            case UpdateCommunityLoading():
              showDialog<void>(
                context: context,
                builder: (context) => const Center(
                  child: CircularProgressIndicator(),
                ),
              );
              break;
            case UpdateCommunitySuccess(:final community):
              Navigator.of(context).pop();
              Navigator.of(context).pop();
              ScaffoldMessenger.of(context).showSnackBar(
                SnackBar(
                  content: Text('${community.name} updated successfully'),
                ),
              );
              break;
            case UpdateCommunityFailure():
              Navigator.of(context).pop();
              break;
            default:
              break;
          }
        },
        builder: (context, state) => CommunityDialog(
          title: const Text('Edit Community'),
          initialName: community.name,
          errorMessage: state is UpdateCommunityFailure ? state.message : null,
          onSubmit: (name) => context.read<UpdateCommunityBloc>().add(
                UpdateCommunity(community.copyWith(name: name)),
              ),
        ),
      ),
    );
  }
}
